==> jc-1.4.0.tar.gz: soot/dava/internal/javaRep/DSpecialInvokeExpr.h <==
// public class soot.dava.internal.javaRep.DSpecialInvokeExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 494ff0846e3e35c8 soot_dava_internal_javaRep_DSpecialInvokeExpr
// @dep_class 7a6f7c3fdc5dcff1 soot_grimp_internal_GSpecialInvokeExpr
// @dep_class a0ee2217a7b698d3 soot_jimple_internal_AbstractInstanceInvokeExpr
// @dep_class 6b76cbc3f8fbbdb7 soot_jimple_internal_AbstractInvokeExpr
// @dep_class c1e420bc363ef3b0 soot_jimple_internal_AbstractSpecialInvokeExpr

// header file dependencies
// @dep_header soot_grimp_internal_GSpecialInvokeExpr

#include "soot/grimp/internal/GSpecialInvokeExpr.h"

#ifndef _JC_soot_dava_internal_javaRep_DSpecialInvokeExpr_H_
#define _JC_soot_dava_internal_javaRep_DSpecialInvokeExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$sub_refs	_jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$sub_refs;
typedef struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$sub_nonrefs	_jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$sub_nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$refs	_jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$refs;
typedef struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$nonrefs	_jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$object	_jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$object;

typedef const struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$vmethods	_jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$vmethods;
typedef const struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$vtable	_jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$vtable;
typedef const struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$vtype	_jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$vtype;

// Constructors
extern void _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$method$_init$737b9105a0ba7cab(_jc_env *, struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$object *, struct _jc_object *, struct _jc_soot_SootMethod$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$object *);
extern struct _jc_java_lang_String$object *_jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$object *);
extern void _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$object *);
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractInvokeExpr$vmethods	soot_jimple_internal_AbstractInvokeExpr;
	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vmethods	soot_jimple_internal_AbstractInstanceInvokeExpr;
	_jc_soot_jimple_internal_AbstractSpecialInvokeExpr$vmethods	soot_jimple_internal_AbstractSpecialInvokeExpr;
	_jc_soot_grimp_internal_GSpecialInvokeExpr$vmethods	soot_grimp_internal_GSpecialInvokeExpr;
	_jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$vmethods	soot_dava_internal_javaRep_DSpecialInvokeExpr;
};

// Vtype
struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$refs {
    _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$sub_refs	soot_dava_internal_javaRep_DSpecialInvokeExpr;
    _jc_soot_grimp_internal_GSpecialInvokeExpr$sub_refs	soot_grimp_internal_GSpecialInvokeExpr;
    _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$sub_refs	soot_jimple_internal_AbstractSpecialInvokeExpr;
    _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_refs	soot_jimple_internal_AbstractInstanceInvokeExpr;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_refs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInstanceInvokeExpr;
    _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractSpecialInvokeExpr;
    _jc_soot_grimp_internal_GSpecialInvokeExpr$sub_nonrefs	soot_grimp_internal_GSpecialInvokeExpr;
    _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$sub_nonrefs	soot_dava_internal_javaRep_DSpecialInvokeExpr;
};

// Object instance structure
struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$object {
	_jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$vtype	*vtype;
	_jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$vtype _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_javaRep_DSpecialInvokeExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$class_object;

#endif	/* _JC_soot_dava_internal_javaRep_DSpecialInvokeExpr_H_ */

==> jc-1.4.6.tar.gz: soot/dava/internal/javaRep/DSpecialInvokeExpr.h <==
// public class soot.dava.internal.javaRep.DSpecialInvokeExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 494ff0846e3e35c8 soot_dava_internal_javaRep_DSpecialInvokeExpr
// @dep_class 7a6f7c3fdc5dcff1 soot_grimp_internal_GSpecialInvokeExpr
// @dep_class a0ee2217a7b698d3 soot_jimple_internal_AbstractInstanceInvokeExpr
// @dep_class 6b76cbc3f8fbbdb7 soot_jimple_internal_AbstractInvokeExpr
// @dep_class c1e420bc363ef3b0 soot_jimple_internal_AbstractSpecialInvokeExpr

// header file dependencies
// @dep_header soot_grimp_internal_GSpecialInvokeExpr

#include "soot/grimp/internal/GSpecialInvokeExpr.h"

#ifndef _JC_soot_dava_internal_javaRep_DSpecialInvokeExpr_H_
#define _JC_soot_dava_internal_javaRep_DSpecialInvokeExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$sub_refs	_jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$sub_refs;
typedef struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$sub_nonrefs	_jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$sub_nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$refs	_jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$refs;
typedef struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$nonrefs	_jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$object	_jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$object;

typedef const struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$vmethods	_jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$vmethods;
typedef const struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$vtable	_jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$vtable;
typedef const struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$vtype	_jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$vtype;

// Constructors
extern void _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$method$_init$737b9105a0ba7cab(_jc_env *, struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$object *, struct _jc_object *, struct _jc_soot_SootMethod$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$object *) _JC_JCNI_ATTR;
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractInvokeExpr$vmethods	soot_jimple_internal_AbstractInvokeExpr;
	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vmethods	soot_jimple_internal_AbstractInstanceInvokeExpr;
	_jc_soot_jimple_internal_AbstractSpecialInvokeExpr$vmethods	soot_jimple_internal_AbstractSpecialInvokeExpr;
	_jc_soot_grimp_internal_GSpecialInvokeExpr$vmethods	soot_grimp_internal_GSpecialInvokeExpr;
	_jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$vmethods	soot_dava_internal_javaRep_DSpecialInvokeExpr;
};

// Vtype
struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$refs {
    _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$sub_refs	soot_dava_internal_javaRep_DSpecialInvokeExpr;
    _jc_soot_grimp_internal_GSpecialInvokeExpr$sub_refs	soot_grimp_internal_GSpecialInvokeExpr;
    _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$sub_refs	soot_jimple_internal_AbstractSpecialInvokeExpr;
    _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_refs	soot_jimple_internal_AbstractInstanceInvokeExpr;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_refs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInstanceInvokeExpr;
    _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractSpecialInvokeExpr;
    _jc_soot_grimp_internal_GSpecialInvokeExpr$sub_nonrefs	soot_grimp_internal_GSpecialInvokeExpr;
    _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$sub_nonrefs	soot_dava_internal_javaRep_DSpecialInvokeExpr;
};

// Object instance structure
struct _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$object {
	_jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$vtype	*vtype;
	_jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$vtype _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_javaRep_DSpecialInvokeExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_javaRep_DSpecialInvokeExpr$class_object;

#endif	/* _JC_soot_dava_internal_javaRep_DSpecialInvokeExpr_H_ */
